complete otool -d 'object file displaying tool' -r
complete otool -s f -d 'print the fat headers' -F
complete otool -s a -d 'print the archive header' -F
complete otool -s h -d 'print the mach header' -F
complete otool -s l -d 'print the load commands' -F
complete otool -s L -d 'print shared libraries used' -F
complete otool -s d -d 'print the data section' -F
complete otool -s D -d 'print shared library id name' -F
complete otool -s o -d 'print the Obj-C segment' -F
complete otool -s r -d 'print the relocation entries' -F
complete otool -s I -d 'print the indirect symbol table' -F
complete otool -s C -d 'print linker optimization hints' -F
complete otool -s G -d 'print the data in code table' -F
complete otool -s c -d 'print arg  of a core file' -F
complete otool -s s -d 'print contents of <seg> <sect>' -x
complete otool -s P -d 'print Info.plist section' -F
complete otool -s x -d 'print all text sections' -F
complete otool -s p -d 'specify routine to dissassemble' -x
complete otool -s v -d 'print verbosely'
complete otool -s V -d 'symbolicate disassembled operands'
complete otool -s X -d 'omit leading addresses, headers'
complete otool -s m -d "disable archive(member) syntax"
complete otool -s B -d 'ARM only: force Thumb disassembly'
complete otool -s q -d "(default) use llvm's disassembler"
complete otool -s Q -d "use otool's disassembler"
complete otool -o mcpu -d 'specify cpu for disassembly'
complete otool -s j -d 'print opcode bytes'
complete otool -l version -f -d "print the version"
