if [ -f /etc/shells ]
then
    sed -i -e '\|^/bin/fish$|d' /etc/shells
    sed -i -e '\|^/usr/bin/fish$|d' /etc/shells
fi

if [ -f /etc/fish/conf.d/00_PATH.fish ] && cmp -s /etc/defaults/etc/fish/conf.d/00_PATH.fish /etc/fish/conf.d/00_PATH.fish
then
    rm /etc/fish/conf.d/00_PATH.fish
fi

if [ -f /etc/fish/conf.d/01_fish_variables.fish ] && cmp -s /etc/defaults/etc/fish/conf.d/01_fish_variables.fish /etc/fish/conf.d/01_fish_variables.fish
then
    rm /etc/fish/conf.d/01_fish_variables.fish
fi

if [ -f /etc/fish/conf.d/cygwin.fish ] && cmp -s /etc/defaults/etc/fish/conf.d/cygwin.fish /etc/fish/conf.d/cygwin.fish
then
    rm /etc/fish/conf.d/cygwin.fish
fi

if [ -f /etc/fish/config.fish ] && cmp -s /etc/defaults/etc/fish/config.fish /etc/fish/config.fish
then
    rm /etc/fish/config.fish
fi

