complete -c entr -s a -d 'Respond to all events'
complete -c entr -s c -d 'Clear the screen before running'
complete -c entr -s d -d 'Track directories and exit if new file added'
complete -c entr -s n -d 'Run in non-interactive mode'
complete -c entr -s p -d 'Postpone execution of utility until a file is modified'
complete -c entr -s r -d 'Launch utility at startup and reload on file change'
complete -c entr -s s -d 'Evaluate using the interpreter in SHELL env variable'
complete -c entr -s z -d 'Exit after utility completes'
complete -c entr -x -a '(__fish_complete_subcommand)'
