complete -c wicd-cli -s h -l help -d 'Print help and exit'
complete -c wicd-cli -s S -l scan -d 'Scan for networks'
complete -c wicd-cli -s l -l list-networks -d 'List networks'
complete -c wicd-cli -s d -l network-details -d 'Show network details'
complete -c wicd-cli -s x -l disconnect -d Disconnect
complete -c wicd-cli -s c -l connect -d Connect
complete -c wicd-cli -s e -l list-encryption-types -d 'List encryption types'
complete -c wicd-cli -s y -l wireless -d 'Perform operation on wireless network'
complete -c wicd-cli -s z -l wired -d 'Perform operation on wired network'
complete -c wicd-cli -s w -l save -d 'Save profile'
complete -c wicd-cli -s o -l load-profile -d 'Load profile'
complete -c wicd-cli -s m -l name -d 'Set name for profile to save/load'
complete -c wicd-cli -s p -l network-property -r -d 'Get or set network property'
complete -c wicd-cli -s s -l set-to -r -d 'Set network property to'
complete -c wicd-cli -s n -l network -d 'Set the network'
