complete -c pinky -a "(__fish_complete_users)" -f
complete -c pinky -s l -d "produce long format output for the specified USERs"
complete -c pinky -s b -d "omit the user's home directory and shell in long format"
complete -c pinky -s h -d "omit the user's project file in long format"
complete -c pinky -s p -d "omit the user's plan file in long format"
complete -c pinky -s s -d "do short format output, this is the default"
complete -c pinky -s f -d "omit the line of column headings in short format"
complete -c pinky -s w -d "omit the user's full name in short format"
complete -c pinky -s i -d "omit the user's full name and remote host in short format"
complete -c pinky -s q -d "omit the user's full name, remote host and idle time in short format"
complete -c pinky -l help -d "display this help and exit"
complete -c pinky -l version -d "output version information and exit"
