
complete -c block -s h -l help -d 'Display help and exit'
complete -c block -s e -l erase -d 'Remove the topmost global event block'
complete -c block -s l -l local -d 'Create a local (automatically erased) event block'
complete -c block -s g -l global -d 'Create a global (manually erased) event block'
