complete -c wslpath -s a -d 'force result to absolute path format'
complete -c wslpath -s u -d 'translate from a Windows path to a WSL path (default)'
complete -c wslpath -s w -d 'translate from a WSL path to a Windows path'
complete -c wslpath -s m -d 'translate from a WSL path to a Windows path, with \'/\' instead of \'\\\''
