complete -c xed -s '?' -s h -l help -d 'Show help and exit'
complete -c xed -l version -d 'Show version and exit'
complete -c xed -l help-all -d 'Show all options and exit'

complete -c xed -l display -d 'X display'
complete -c xed -l encoding -d Encoding
complete -c xed -l new-window -d 'Create a new window'
complete -c xed -l new-document -d 'Create a new document'
complete -c xed -l list-encodings -d 'List encodings'
