# Completions for Docutils common options
__fish_complete_docutils rst2html

# Completions for Docutils standalone reader options
__fish_complete_docutils_standalone_reader rst2html

# Completions for Docutils HTML options
__fish_complete_docutils_html rst2html
