# Completions for Docutils common options
__fish_complete_docutils rst2latex

# Completions for Docutils standalone reader options
__fish_complete_docutils_standalone_reader rst2latex

# Completions for Docutils LaTeX options
__fish_complete_docutils_latex rst2latex
