complete -c tcsh -l help -d 'Display help and exit'
complete -c tcsh -l version -d 'Display version and exit'

complete -c tcsh -s b -d 'Stop option processing'
complete -c tcsh -s c -d 'Specify commands'
complete -c tcsh -s d -d 'Load directory stack from ~/.tcshdirs'
complete -c tcsh -s D -d 'Specify environment variable'
complete -c tcsh -s e -d 'Exit when exit status is not zero'
complete -c tcsh -s f -d 'Do not load resource and startup files'
complete -c tcsh -s F -d 'Use fork instead of vfork'
complete -c tcsh -s i -d 'Use interactive mode'
complete -c tcsh -s l -d 'Use login shell'
complete -c tcsh -s m -d 'Load ~/.ttcshrc'
complete -c tcsh -s n -d 'Parse commands without executing'
complete -c tcsh -s q -d 'Accept SIGQUIT'
complete -c tcsh -s s -d 'Specify commands via stdin'
complete -c tcsh -s t -d 'Read and execute single input line'
complete -c tcsh -s v -d 'Set `verbose` shell variable'
complete -c tcsh -s x -d 'Set `echo` shell variable'
complete -c tcsh -s V -d 'Set `verbose` shell variable'
complete -c tcsh -s X -d 'Set `echo` shell variable'
